@@ -16,10 +16,6 @@
 #' @param skipGeometry This option can be used to skip response geometries for
 #' each feature. The returning object will be a data frame with no spatial
 #' information.
-#' @param limit The optional limit parameter limits the number of items that are
-#' presented in the response document. Only items are counted that are on the
-#' first level of the collection in the response document. Nested objects
-#' contained within the explicitly requested items shall not be counted.
 #' @keywords internal
 #' @examples
 #' site <- "USGS-02238500"
@@ -43,51 +39,47 @@
 construct_api_requests <- function(service,
                                    properties = NA_character_,
                                    bbox = NA,
-                                   limit = NA,
-                                   max_results = NA,
                                    skipGeometry = FALSE,
+                                   no_paging = FALSE,
                                    ...){
   
-  baseURL <- setup_api(service)
-  
   POST <- FALSE
   
-  single_params <- c("datetime", "last_modified", "begin", "end", "time")
+  single_params <- c("datetime", "last_modified", 
+                     "begin", "end", "time", "limit",
+                     "begin_utc", "end_utc")
+  comma_params <- c("monitoring_location_id", "parameter_code", 
+                    "statistic_id", "time_series_id",
+                    "computation_period_identifier",
+                    "computation_identifier")
+  
+  if(service %in% c("monitoring-locations", "parameter-codes", 
+                    "time-series-metadata")){
+    comma_params <- c(comma_params, "id")
+  }
   
   full_list <- list(...)
   
   if(all(is.na(full_list)) & all(is.na(bbox))){
     warning("No filtering arguments specified.")
   }
+  # Figure out if the GET request will be > 2048 characters
+  comma_params_filtered <- Filter(Negate(anyNA), full_list[comma_params])
+
+  force_post <- nchar(paste0(unlist(comma_params_filtered), collapse = ",")) > 2048
   
-  get_list <- full_list[names(full_list) %in% single_params]
+  if(force_post){
+    get_list <- full_list[names(full_list) %in% c(single_params)]
+  } else {
+    # GET list refers to arguments that will go in the URL no matter what (not POST)
+    get_list <- full_list[names(full_list) %in% c(single_params, comma_params)]    
+  }
 
   get_list[["skipGeometry"]] <- skipGeometry
   
-  if(is.na(limit)){
-    if(!is.na(max_results)){
-      get_list[["limit"]] <- max_results
-    } else {
-      get_list[["limit"]] <- 10000
-    }
-  } else {
-    if(!is.na(max_results)){
-      if(limit > max_results) stop("limit cannot be greater than max_result")
-    }
-    get_list[["limit"]] <- limit
-  }
-  
-  post_list <- full_list[!names(full_list) %in% single_params]
-  
-  post_params <- explode_post(post_list)
-  
-  if(length(post_params) > 0){
-    POST = TRUE
-  }
-  
   get_list <- get_list[!is.na(get_list)]
   
-  time_periods <- c("last_modified", "datetime", "time", "begin", "end")
+  time_periods <- c("last_modified", "datetime", "time", "begin", "end", "begin_utc", "end_utc")
   if(any(time_periods %in% names(get_list))){
 
     for(i in time_periods[time_periods %in% names(get_list)]){
@@ -100,7 +92,10 @@ construct_api_requests <- function(service,
     }
   }
   
-  baseURL <- explode_query(baseURL, POST = FALSE, get_list)
+  format_type <- ifelse(isTRUE(no_paging), "csv", "json")
+  
+  baseURL <- setup_api(service, format = format_type)
+  baseURL <- explode_query(baseURL, POST = FALSE, get_list, multi = "comma")
   
   if(all(!is.na(bbox))){
     baseURL <- httr2::req_url_query(baseURL,
@@ -109,12 +104,32 @@ construct_api_requests <- function(service,
   }
   
   if(!all(is.na(properties))){
+    available_properties <- property_list[[service]]
+    
+    if(!all(properties %in% available_properties)){
+      # Check again:
+      schema <- check_OGC_requests(endpoint = service, type = "schema")
+      properties_fresh <- names(schema$properties)
+      if(!all(properties %in% properties_fresh)){
+        stop("Invalid properties: ", 
+             paste0(properties[!properties %in% properties_fresh], collapse = ", "))
+      }
+    }
+    
     baseURL <- httr2::req_url_query(baseURL,
                                     properties = properties,
                                     .multi = "comma")    
   }
   
-  if(POST){  
+  #POST list are the arguments that need to be in the POST body
+  post_list <- full_list[!names(full_list) %in% names(get_list)]
+  
+  post_params <- explode_post(post_list)
+  
+  # Should we do a POST?
+  POST = length(post_params) > 0
+  
+  if(POST){
     baseURL <- baseURL |>
       httr2::req_headers(`Content-Type` = "application/query-cql-json") 
     
@@ -129,12 +144,22 @@ construct_api_requests <- function(service,
     baseURL <- httr2::req_body_raw(baseURL, x) 
     
   } else {
-    baseURL <- explode_query(baseURL, POST = FALSE, full_list)
+    baseURL <- explode_query(baseURL, POST = FALSE, full_list, multi = "comma")
   }
   
   return(baseURL)
 }
 
+check_limits <- function(args){
+  current_api_limit <- 50000
+  
+  if(is.na(args[["limit"]])){
+    args[["limit"]] <- current_api_limit
+  } 
+  
+  return(args)
+}
+
 #' Setup the request for the OGC API requests
 #' 
 #' @noRd
@@ -161,12 +186,12 @@ base_url <- function(){
 #' request <- dataRetrieval:::setup_api("daily")
 #' request
 #' }
-setup_api <- function(service){
+setup_api <- function(service, format = "json"){
   
   baseURL <- base_url() |> 
     httr2::req_url_path_append("collections") |> 
     httr2::req_url_path_append(service, "items") |> 
-    basic_request() 
+    basic_request(format = format) 
   
 }
 
@@ -207,76 +232,6 @@ switch_arg_id <- function(ls, id_name, service){
   return(ls)
 }
 
-#' Switch properties id
-#' 
-#' @noRd
-#' @return list
-#' @examples
-#' 
-#' properties <- c("id", "state_name", "country_name")
-#' dataRetrieval:::switch_properties_id(properties, 
-#'                               id_name = "monitoring_location_id",
-#'                               service = "monitoring-locations")
-#'                               
-#' properties2 <- c("monitoring_location_id", "state_name", "country_name")
-#' dataRetrieval:::switch_properties_id(properties2, 
-#'                               id_name = "monitoring_location_id",
-#'                               service = "monitoring-locations")
-#'                               
-#' properties3 <- c("monitoring_locations_id", "state_name", "country_name")
-#' dataRetrieval:::switch_properties_id(properties3, 
-#'                               id_name = "monitoring_location_id",
-#'                               service = "monitoring-locations")
-switch_properties_id <- function(properties, id_name, service){
-  
-  service_id <- paste0(gsub("-", "_", service), "_id")
-  
-  last_letter <- substr(service, nchar(service), nchar(service))
-  if(last_letter == "s"){
-    service_singluar <- substr(service,1, nchar(service)-1)
-    service_id_singular <- paste0(gsub("-", "_", service_singluar), "_id")
-  } else {
-    service_id_singular <- ""
-  }
-  
-  if(!"id" %in% properties){
-    if(service_id %in% properties){
-      properties[properties == service_id] <- "id"
-      
-    } else if(service_id_singular %in% properties) {
-      properties[properties == service_id_singular] <- "id"
-    } else {
-      properties[properties == id_name] <- "id"
-    }
-  }
-  
-  if(!all(is.na(properties))){
-
-    schema <- check_OGC_requests(endpoint = service,
-                                 type = "schema")
-    all_properties <- names(schema$properties)
-    
-    if(all(all_properties[!all_properties %in% c("id", "geometry")] %in% properties)) {
-      # Cleans up URL if we're asking for everything
-      properties <- NA_character_
-    } else {
-      properties <- gsub("-", "_", properties)
-      properties <- properties[!properties %in% c("id", 
-                                                  "geometry",
-                                                  paste0(gsub("-", "_", service), "_id"))]
-    
-    }
-    
-    if(!all(is.na(properties))){
-      match.arg(properties, choices = all_properties,
-                several.ok = TRUE)    
-    }
-  }
-  
-  return(properties)
-}
-
-
 #' Format the date request
 #' 
 #' Users will want to give either start/end dates or 
@@ -327,6 +282,11 @@ switch_properties_id <- function(properties, id_name, service){
 #' start_end2 <- c("2021-01-01T12:15:00-0500", "")
 #' dataRetrieval:::format_api_dates(start_end2)
 #' 
+#' time = c("2014-05-01T00:00:00Z", "2014-05-01T12:00:00Z")
+#' dataRetrieval:::format_api_dates(time)
+#' 
+#' time = c("2014-05-01T00:00Z", "2014-05-01T12:00Z")
+#' dataRetrieval:::format_api_dates(time)
 format_api_dates <- function(datetime, date = FALSE){
   
   if(is.character(datetime)){
@@ -340,19 +300,31 @@ format_api_dates <- function(datetime, date = FALSE){
          grepl("/", datetime)){
         return(datetime)
       } else {
+        datetime1 <- tryCatch({
+            lubridate::as_datetime(datetime)
+          },
+          warning = function(w) {
+            strptime(datetime, format = "%Y-%m-%dT%H:%MZ", tz = "UTC")
+        })
         if(date){
-          datetime <- format(lubridate::as_datetime(datetime), "%Y-%m-%d")
+          datetime <- format(datetime1, "%Y-%m-%d")
         } else {
-          datetime <- lubridate::format_ISO8601(lubridate::as_datetime(datetime), usetz = "Z")
+          datetime <- lubridate::format_ISO8601(datetime1, usetz = "Z")
         }
       }
     } else if (length(datetime) == 2) {
       
+      datetime1 <- tryCatch({
+          lubridate::as_datetime(datetime)
+        },
+        warning = function(w) {
+          strptime(datetime, format = "%Y-%m-%dT%H:%MZ", tz = "UTC")
+      })
+      
       if(date){
-        datetime <- paste0(format(lubridate::as_datetime(datetime), "%Y-%m-%d"), collapse = "/")
+        datetime <- paste0(format(datetime1, "%Y-%m-%d"), collapse = "/")
       } else {
-        datetime <- paste0(lubridate::format_ISO8601(lubridate::as_datetime(datetime), 
-                                                     usetz = "Z"), 
+        datetime <- paste0(lubridate::format_ISO8601(datetime1, usetz = "Z"), 
                            collapse = "/")
       }
 
@@ -425,47 +397,7 @@ cql2_param <- function(parameter){
   return(whisker::whisker.render(template, parameter_list))
 } 
 
-#' Check OGC requests
-#' 
-#' @param endpoint Character, can be any existing collection
-#' @param type Character, can be "queryables", "schema"
-#' @export
-#' @keywords internal
-#' @return list
-#' @examplesIf is_dataRetrieval_user()
-#' 
-#' \donttest{
-#' 
-#' dv_queryables <- check_OGC_requests(endpoint = "daily",
-#'                                 type = "queryables")
-#' dv_schema <- check_OGC_requests(endpoint = "daily",
-#'                             type = "schema")
-#' ts_meta_queryables <- check_OGC_requests(endpoint = "time-series-metadata",
-#'                                 type = "queryables")
-#' ts_meta_schema <- check_OGC_requests(endpoint = "time-series-metadata",
-#'                                 type = "schema")
-#' }
-check_OGC_requests <- function(endpoint = "daily",
-                               type = "queryables"){
-  
-  match.arg(type, c("queryables", "schema"))
-  
-  match.arg(endpoint, c(pkg.env$api_endpoints,
-                        pkg.env$metadata))
-  
-  req <- base_url() |> 
-    httr2::req_url_path_append("collections") |> 
-    httr2::req_url_path_append(endpoint) |> 
-    httr2::req_url_path_append(type) |> 
-    basic_request()
-  
-  query_ret <- req |> 
-    httr2::req_perform() |> 
-    httr2::resp_body_json() 
-  
-  return(query_ret)
-  
-}
+
 
 #' Custom Error Messages
 #' 
@@ -515,14 +447,15 @@ error_body <- function(resp) {
 #' collect_request
 #' }
 #' 
-basic_request <- function(url_base){
+basic_request <- function(url_base, format = "json"){
   
   req <- url_base |> 
     httr2::req_user_agent(default_ua()) |> 
     httr2::req_headers(`Accept-Encoding` = c("compress", "gzip")) |> 
-    httr2::req_url_query(f = "json",
+    httr2::req_url_query(f = format,
                          lang = "en-US") |> 
-    httr2::req_error(body = error_body) 
+    httr2::req_error(body = error_body) |> 
+    httr2::req_timeout(seconds = 180)
   
   token <- Sys.getenv("API_USGS_PAT")
   
@@ -535,85 +468,4 @@ basic_request <- function(url_base){
   
 }
 
-#' Create service descriptions dynamically
-#' 
-#' This function populates the parameter descriptions.
-#' 
-#' @param service Character, can be any of the endpoints
-#' @return list
-#' @noRd
-#' @examplesIf is_dataRetrieval_user()
-#' 
-#' \donttest{
-#' ml_desc <- dataRetrieval:::get_description("monitoring-locations")
-#' ml_desc
-#' }
-#' 
-get_description <- function(service){
 
-  query_ret <- get_collection() 
-  
-  tags <- query_ret[["tags"]]
-  
-  service_index <- which(sapply(tags, function(x){
-    x$name == service
-  }))
-  
-  tags[[service_index]][["description"]]
-  
-}
-
-#' Get collection response
-#' 
-#' 
-#' @return httr2 response
-#' @noRd
-#' @examplesIf is_dataRetrieval_user()
-#' 
-#' \donttest{
-#' collection <- dataRetrieval:::get_collection()
-#' collection
-#' }
-#' 
-get_collection <- function(){
-  
-  check_collections <- base_url() |> 
-    httr2::req_url_path_append("openapi") |>
-    httr2::req_url_query(f = "html#/server/getCollections")
-  
-  check_endpoints_req <- basic_request(check_collections)
-  
-  query_ret <- httr2::req_perform(check_endpoints_req) |> 
-    httr2::resp_body_json()
-  
-  return(query_ret)
-}
-
-#' Create parameter descriptions dynamically
-#' 
-#' This function populates the parameter descriptions.
-#' 
-#' @param service Character, can be any of the endpoints
-#' @return list
-#' @noRd
-#' @examplesIf is_dataRetrieval_user()
-#' 
-#' \donttest{
-#' ml <- dataRetrieval:::get_params("monitoring-locations")
-#' ml$national_aquifer_code
-#' }
-#' 
-get_params <- function(service){
-  
-  check_queryables_req <- base_url() |> 
-    httr2::req_url_path_append("collections") |> 
-    httr2::req_url_path_append(service) |> 
-    httr2::req_url_path_append("schema") |> 
-    basic_request()
-  
-  query_ret <- httr2::req_perform(check_queryables_req) |> 
-    httr2::resp_body_json() 
-  
-  params <- sapply(query_ret$properties, function(x) x[["description"]]) 
-
-}
