@@ -3,20 +3,26 @@
 #' @description `r get_description("latest-continuous")`
 #' 
 #' @export
-#' @param monitoring_location_id `r get_params("latest-continuous")$monitoring_location_id`
-#' @param parameter_code `r get_params("latest-continuous")$parameter_code`
-#' @param statistic_id `r get_params("latest-continuous")$statistic_id`
-#' @param time `r get_params("latest-continuous")$time`
-#' @param value `r get_params("latest-continuous")$value`
-#' @param unit_of_measure `r get_params("latest-continuous")$unit_of_measure`
-#' @param approval_status `r get_params("latest-continuous")$approval_status`
-#' @param last_modified `r get_params("latest-continuous")$last_modified`
-#' @param time_series_id `r get_params("latest-continuous")$time_series_id`
-#' @param qualifier `r get_params("latest-continuous")$qualifier`
-#' @param latest_continuous_id `r get_params("latest-continuous")$id`
+#' @param monitoring_location_id `r get_ogc_params("latest-continuous")$monitoring_location_id`
+#' Multiple monitoring_location_ids can be requested as a character vector.
+#' @param parameter_code `r get_ogc_params("latest-continuous")$parameter_code`
+#' Multiple parameter_codes can be requested as a character vector.
+#' @param time `r get_ogc_params("latest-continuous")$time`
+#' You can also use a vector of length 2: the first value being the starting date,
+#' the second value being the ending date. NA's within the vector indicate a
+#' half-bound date. For example, c("2024-01-01", NA) will return all data starting
+#' at 2024-01-01.
+#' @param value `r get_ogc_params("latest-continuous")$value`
+#' @param unit_of_measure `r get_ogc_params("latest-continuous")$unit_of_measure`
+#' @param approval_status `r get_ogc_params("latest-continuous")$approval_status`
+#' @param last_modified `r get_ogc_params("latest-continuous")$last_modified`
+#' @param time_series_id `r get_ogc_params("latest-continuous")$time_series_id`
+#' Multiple time_series_ids can be requested as a character vector.
+#' @param qualifier `r get_ogc_params("latest-continuous")$qualifier`
 #' @param properties A vector of requested columns to be returned from the query.
 #' Available options are: 
-#' `r schema <- check_OGC_requests(endpoint = "latest-continuous", type = "schema"); paste(names(schema$properties), collapse = ", ")`
+#' `r dataRetrieval:::get_properties_for_docs("latest-continuous", "latest_continuous_id")`.
+#' The default (`NA`) will return all columns of the data.
 #' @param bbox Only features that have a geometry that intersects the bounding
 #' box are selected.The bounding box is provided as four or six numbers, depending
 #' on whether the coordinate reference system includes a vertical axis (height or
@@ -25,16 +31,18 @@
 #' Southern-most latitude, Eastern-most longitude, Northern-most longitude).
 #' @param limit The optional limit parameter is used to control the subset of the 
 #' selected features that should be returned in each page. The maximum allowable
-#' limit is 10000. It may be beneficial to set this number lower if your internet
+#' limit is 50000. It may be beneficial to set this number lower if your internet
 #' connection is spotty. The default (`NA`) will set the limit to the maximum
 #' allowable limit for the service.
-#' @param max_results The optional maximum number of rows to return. This value
-#' must be less than the requested limit. 
 #' @param skipGeometry This option can be used to skip response geometries for
 #' each feature. The returning object will be a data frame with no spatial
 #' information.
 #' @param convertType logical, defaults to `TRUE`. If `TRUE`, the function
 #' will convert the data to dates and qualifier to string vector.
+#' @param no_paging logical, defaults to `FALSE`. If `TRUE`, the data will
+#' be requested from a native csv format. This can be dangerous because the
+#' data will cut off at 50,000 rows without indication that more data
+#' is available. Use `TRUE` with caution. 
 #' @examplesIf is_dataRetrieval_user()
 #' 
 #' \donttest{
@@ -71,10 +79,8 @@
 #' }
 read_waterdata_latest_continuous <- function(monitoring_location_id = NA_character_,
                             parameter_code = NA_character_,
-                            statistic_id = NA_character_,
                             properties = NA_character_,
                             time_series_id = NA_character_,
-                            latest_continuous_id = NA_character_,
                             approval_status = NA_character_,
                             unit_of_measure = NA_character_,
                             qualifier = NA_character_,
@@ -84,8 +90,8 @@ read_waterdata_latest_continuous <- function(monitoring_location_id = NA_charact
                             time = NA_character_,
                             bbox = NA,
                             limit = NA,
-                            max_results = NA,
-                            convertType = TRUE){
+                            convertType = TRUE,
+                            no_paging = FALSE){
   
   service <- "latest-continuous"
   output_id <- "latest_continuous_id"
@@ -94,8 +100,6 @@ read_waterdata_latest_continuous <- function(monitoring_location_id = NA_charact
   return_list <- get_ogc_data(args,
                               output_id, 
                               service)
-
-  return_list <- return_list[order(return_list$time, return_list$monitoring_location_id), ]
   
   return(return_list)
 }
