@@ -12,11 +12,11 @@
 #' "topographic-codes", "time-zone-codes".
 #' @param limit The optional limit parameter is used to control the subset of the 
 #' selected features that should be returned in each page. The maximum allowable
-#' limit is 10000. It may be beneficial to set this number lower if your internet
+#' limit is 50000. It may be beneficial to set this number lower if your internet
 #' connection is spotty. The default (`NA`) will set the limit to the maximum
 #' allowable limit for the service.
-#' @param max_results The optional maximum number of rows to return. This value
-#' must be less than the requested limit. 
+#' @param \dots Optional arguments to pass to the query. Available parameters
+#' can be found with the \code{get_ogc_params} function.
 #' @examplesIf is_dataRetrieval_user()
 #' 
 #' \donttest{
@@ -24,6 +24,8 @@
 #' altitude_datums <- read_waterdata_metadata("altitude-datums")
 #' aquifer_codes <- read_waterdata_metadata("aquifer-codes")
 #' aquifer_types <- read_waterdata_metadata("aquifer-types")
+#' counties <- read_waterdata_metadata("counties")
+#' us_counties <- read_waterdata_metadata("counties", country_code = "US")
 #' coordinate_accuracy_codes <- read_waterdata_metadata("coordinate-accuracy-codes")
 #' coordinate_datum_codes <- read_waterdata_metadata("coordinate-datum-codes")
 #' coordinate_method_codes <- read_waterdata_metadata("coordinate-method-codes")
@@ -32,46 +34,42 @@
 #' parameter_codes <- read_waterdata_metadata("parameter-codes")
 #' reliability_codes <- read_waterdata_metadata("reliability-codes")
 #' site_types <- read_waterdata_metadata("site-types")
+#' states <- read_waterdata_metadata("states")
+#' us_states_territories <- read_waterdata_metadata("states", country_code = "US")
 #' statistic_codes <- read_waterdata_metadata("statistic-codes")
 #' topographic_codes <- read_waterdata_metadata("topographic-codes")
 #' time_zone_codes <- read_waterdata_metadata("time-zone-codes")
+#' time_zone_limited <- read_waterdata_metadata("time-zone-codes",
+#'                         time_zone_description = c("Alaska", "Hawaii", "Pacific North America"))
 #' }
 read_waterdata_metadata <- function(collection, 
-                          max_results = NA,
-                          limit = NA){
-
-  available <- c("parameter-codes", "agency-codes", "altitude-datums", "aquifer-codes",
-                 "aquifer-types", "coordinate-accuracy-codes", "coordinate-datum-codes",
-                 "coordinate-method-codes", "hydrologic-unit-codes", "medium-codes", 
-                 "national-aquifer-codes", "reliability-codes", "site-types", "statistic-codes",
-                 "topographic-codes", "time-zone-codes")
+                                    limit = NA,
+                                    ...){
   
-  match.arg(collection, available)
+  match.arg(collection, pkg.env$metadata)
 
-  output_id <- gsub("-", "_", collection)
-  last_letter <- substr(output_id, 
-                        start = nchar(output_id),
-                        stop = nchar(output_id))
-  if(last_letter == "s"){
-    output_id <- substr(output_id, 
-                        start = 1,
-                        stop = nchar(output_id)-1)    
+  output_id <- names(pkg.env$metadata)[pkg.env$metadata == collection]
+  
+  args <- list(...)
+  
+  if(length(args) > 0){
+    possible_args <- get_ogc_params(collection)
+    if(!all(names(args) %in% names(possible_args))){
+      wrong_args <- names(args)[!names(args) %in% names(possible_args)]
+      wrong_args <- paste0(wrong_args, collapse = ", ")
+      stop(paste0("Unknown argument: ", wrong_args))
+    }
   }
   
-  data_req <- suppressWarnings(construct_api_requests(service = collection, 
-                                                      skipGeometry = TRUE, 
-                                                      properties = NA,
-                                                      limit = limit, 
-                                                      max_results = max_results))
+  args[["limit"]] <- limit
+  args[["convertType"]] <- FALSE
+  args[["skipGeometry"]] <- TRUE
+  args[["bbox"]] <- NA
+  args[["no_paging"]] <- FALSE # drops id if TRUE
   
-  return_list <- walk_pages(data_req, max_results)
-
-  return_list <- rejigger_cols(df = return_list,
-                               properties =  NA,
-                               output_id =  output_id)
-  
-  attr(return_list, "request") <- data_req
-  attr(return_list, "queryTime") <- Sys.time()
+  return_list <- get_ogc_data(args = args,
+                              output_id = output_id,
+                              service =  collection)
   
   return(return_list)
 }
